@@ -29,12 +29,6 @@
  * 4. This notice may not be removed or altered.
  */
 
-#ifndef lint
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-#endif
-
-
 #include "lsof.h"
 
 #if	defined(HASEPTOPTS) && defined(HASPTYEPT)
@@ -139,7 +133,7 @@ endpoint_pxinfo_hash(pxinfo_t **pinfo_hash, const size_t nbuckets,
 		do {
 		    pp = pi->next;
 		    (void) (* free_elt)
-		    ((FREE_P *)pi);
+			((FREE_P *)pi);
 		    pi = pp;
 		} while (pi);
 		pinfo_hash[h] = (pxinfo_t *)NULL;
@@ -178,7 +172,7 @@ endpoint_enter(pxinfo_t **pinfo_hash, const char *table_name, int id)
 		"%s: no space for pipeinfo for %s, PID %d, FD %s\n",
 		table_name,
 		Pn, Lp->pid, Lf->fd);
-	    Exit(1);
+	    Error();
 	}
 	np->ino = id;
 	np->lf = Lf;
@@ -258,7 +252,7 @@ enter_pinfo()
 	    {
 		(void) fprintf(stderr,
 		    "%s: no space for %d pipe info buckets\n", Pn, PINFOBUCKS);
-		    Exit(1);
+		Error();
 	    }
 	}
 	endpoint_enter(Pinfo, "pipeinfo", Lf->inode);
@@ -314,7 +308,7 @@ enter_ptmxi(mn)
 	    {
 		(void) fprintf(stderr,
 		    "%s: no space for %d pty info buckets\n", Pn, PINFOBUCKS);
-		    Exit(1);
+		Error();
 	    }
 	}
 	endpoint_enter(PtyInfo, "pty", mn);
@@ -373,19 +367,19 @@ is_pty_slave(sm)
 	/* linux/Documentation/admin-guide/devices.txt
 	   -------------------------------------------
 	   136-143 char	Unix98 PTY slaves
-		  0 = /dev/pts/0	First Unix98 pseudo-TTY
-		  1 = /dev/pts/1	Second Unix98 pseudo-TTY
-		    ...
+	   0 = /dev/pts/0	First Unix98 pseudo-TTY
+	   1 = /dev/pts/1	Second Unix98 pseudo-TTY
+	   ...
 
-		These device nodes are automatically generated with
-		the proper permissions and modes by mounting the
-		devpts filesystem onto /dev/pts with the appropriate
-		mount options (distribution dependent, however, on
-		*most* distributions the appropriate options are
-		"mode=0620,gid=<gid of the "tty" group>".) */
+	   These device nodes are automatically generated with
+	   the proper permissions and modes by mounting the
+	   devpts filesystem onto /dev/pts with the appropriate
+	   mount options (distribution dependent, however, on
+	   *most* distributions the appropriate options are
+	   "mode=0620,gid=<gid of the "tty" group>".) */
 	if ((UNIX98_PTY_SLAVE_MAJOR <= sm)
 	&&  (sm < (UNIX98_PTY_SLAVE_MAJOR + UNIX98_PTY_MAJOR_COUNT))
-	) {
+	    ) {
 	    return 1;
 	}
 	return 0;
@@ -436,7 +430,7 @@ enter_psxmqinfo()
 	    {
 		(void) fprintf(stderr,
 		    "%s: no space for %d posix mq info buckets\n", Pn, PINFOBUCKS);
-		    Exit(1);
+		Error();
 	    }
 	}
 	endpoint_enter(PSXMQinfo, "psxmqinfo", Lf->inode);
@@ -487,7 +481,7 @@ enter_evtfdinfo(int id)
 	    {
 		(void) fprintf(stderr,
 		    "%s: no space for %d envet fd info buckets\n", Pn, PINFOBUCKS);
-		    Exit(1);
+		Error();
 	    }
 	}
 	endpoint_enter(EvtFDinfo, "evtfdinfo", id);
@@ -536,7 +530,7 @@ get_fields(ln, sep, fr, eb, en)
 
 	for (cp = ln, n = 0; cp && *cp;) {
 	    for (bp = cp; *bp && (*bp == ' ' || *bp == '\t'); bp++);
-		;
+	    ;
 	    if (!*bp || *bp == '\n')
 		break;
 	    for (cp = bp; *cp; cp++) {
@@ -606,7 +600,7 @@ get_fields(ln, sep, fr, eb, en)
 		    (void) fprintf(stderr,
 			"%s: can't allocate %d bytes for field pointers.\n",
 			Pn, (int)len);
-		    Exit(1);
+		    Error();
 		}
 	    }
 	    fp[n++] = bp;
@@ -657,7 +651,7 @@ get_locks(p)
 		(void) fprintf(stderr,
 		    "%s: can't allocate %d lock hash bytes\n",
 		    Pn, (int)(sizeof(struct llock *) * PIDBUCKS));
-		Exit(1);
+		Error();
 	    }
 	}
 /*
@@ -751,7 +745,7 @@ get_locks(p)
 		(void) fprintf(stderr,
 		    "%s: can't allocate llock: PID %d; dev %x; inode %s\n",
 		    Pn, pid, (int)dev, buf);
-		Exit(1);
+		Error();
 	    }
 	    lp->pid = pid;
 	    lp->dev = dev;
@@ -816,7 +810,7 @@ process_proc_node(p, pbr, s, ss, l, ls)
 		return;
 	    case 0:
 		if (!strcmp(p, "anon_inode"))
-		   Lf->ntype = Ntype = N_ANON_INODE;
+		    Lf->ntype = Ntype = N_ANON_INODE;
 		break;
 	    }
 	}
@@ -838,7 +832,7 @@ process_proc_node(p, pbr, s, ss, l, ls)
 		if (FeptE
 		&&  (Ntype == N_CHR)
 		&&  is_pty_slave(GET_MAJ_DEV(Lf->rdev))
-		) {
+		    ) {
 		    enter_ptmxi(GET_MIN_DEV(Lf->rdev));
 		    Lf->sf |= SELPTYINFO;
 		}
@@ -852,7 +846,7 @@ process_proc_node(p, pbr, s, ss, l, ls)
 		&&  (mp->ds & SB_DEV) && Lf->dev_def && (Lf->dev == mp->dev)
 		&&  (mp->dir && mp->dirl
 		&&   !strncmp(mp->dir, p, mp->dirl))
-		) {
+		    ) {
 		    Lf->ntype = Ntype = N_NFS;
 		    break;
 		}
@@ -888,14 +882,14 @@ process_proc_node(p, pbr, s, ss, l, ls)
 	case N_BLK:
 	case N_CHR:
 	case N_FIFO:
-	    if (!Fsize && l && (ls & SB_SIZE) && OffType) {
+	    if (!Fsize && l && (ls & SB_SIZE) && OffType != OFFSET_UNKNOWN) {
 		Lf->off = (SZOFFTYPE)l->st_size;
 		Lf->off_def = 1;
 	    }
 	    break;
 	default:
 	    if (Foffset) {
-		if (l && (ls & SB_SIZE) && OffType) {
+		if (l && (ls & SB_SIZE) && OffType != OFFSET_UNKNOWN) {
 		    Lf->off = (SZOFFTYPE)l->st_size;
 		    Lf->off_def = 1;
 		}
