@@ -30,15 +30,10 @@
  */
 
 
-#include "../machine.h"
+#include "machine.h"
 
 #if	defined(HASNCACHE) && defined(USE_LIB_RNCH)
 
-# if	!defined(lint)
-static char copyright[] =
-"@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-# endif	/* !defined(lint) */
-
 #include "../lsof.h"
 
 
@@ -303,7 +298,7 @@ ncache_isroot(va, cp)
 	    if (!vc) {
 		(void) fprintf(stderr, "%s: no space for root vnode table\n",
 		    Pn);
-		Exit(1);
+		Error();
 	    }
 	}
 	vc[vcn++] = va;
@@ -428,7 +423,7 @@ ncache_load()
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 			"%s: can't allocate name cache space: %d\n", Pn, len);
-		Exit(1);
+		Error();
 	    }
 # endif	/* !defined(NCACHE_NXT) */
 
@@ -443,7 +438,7 @@ no_local_space:
 		if (!Fwarn)
 		    (void) fprintf(stderr,
 		      "%s: no space for %d byte local name cache\n", Pn, len);
-		Exit(1);
+		Error();
 	    }
 	} else {
 
@@ -532,7 +527,7 @@ no_local_space:
 		    (void) fprintf(stderr,
 			"%s: can't allocate %d byte temporary name buffer\n",
 			Pn, na);
-		    Exit(1);
+		    Error();
 		}
 	    }
 	    if (!kc->NCACHE_NAME || kread((KA_T)kc->NCACHE_NAME, nb, len))
@@ -558,7 +553,7 @@ no_local_space:
 		(void) fprintf(stderr,
 		    "%s: can't allocate %d bytes for name cache name: %s\n",
 		    Pn, len + 1, np);
-		Exit(1);
+		Error();
 	    }
 	    (void) strncpy(cp, np, len);
 	    cp[len] = '\0';
@@ -577,7 +572,7 @@ no_local_space:
 		    (void) fprintf(stderr,
 			"%s: no more space for %d entry local name cache\n",
 			Pn, Nc);
-		    Exit(1);
+		    Error();
 		}
 		lc = &Ncache[n];
 		iNc = Nc;
@@ -664,7 +659,7 @@ no_local_space:
 		(void) fprintf(stderr,
 		    "%s: no space for %d name cache hash pointers\n",
 		    Pn, Nch + Nc);
-	    Exit(1);
+	    Error();
 	}
 	for (i = 0, lc = Ncache; i < Nc; i++, lc++) {
 
@@ -710,7 +705,7 @@ no_local_space:
 # else	/* !defined(NCACHE_NODEID) */
 	    lc->pa = ncache_addr(lc->dp);
 # endif	/* defined(NCACHE_NODEID) */
-	
+
 	}
 }
 
