@@ -29,12 +29,6 @@
  * 4. This notice may not be removed or altered.
  */
 
-#ifndef lint
-static char copyright[] =
-"@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-#endif
-
-
 #include "lsof.h"
 
 #if	defined(HASEPTOPTS)
@@ -71,7 +65,7 @@ add_nma(cp, len)
 	if (!Lf->nma) {
 	    (void) fprintf(stderr, "%s: no name addition space: PID %ld, FD %s",
 		Pn, (long)Lp->pid, Lf->fd);
-	    Exit(1);
+	    Error();
 	}
 	if (nl) {
 	    Lf->nma[nl] = ' ';
@@ -110,7 +104,7 @@ alloc_fflbuf(bp, al, lr)
 	if (!*bp) {
 	    (void) fprintf(stderr, "%s: no space (%d) for print flags\n",
 		Pn, sz);
-	    Exit(1);
+	    Error();
 	}
 	*al = sz;
 	return(*bp);
@@ -149,19 +143,19 @@ alloc_lfile(nm, num)
 /*
  * Othwerise, allocate a new structure.
  */
-	} else if (!(Lf = (struct lfile *)malloc(sizeof(struct lfile)))) {
+		} else if (!(Lf = (struct lfile *)malloc(sizeof(struct lfile)))) {
 	    (void) fprintf(stderr, "%s: no local file space at PID %d\n",
 		Pn, Lp->pid);
-	    Exit(1);
+	    Error();
 	}
 /*
  * Initialize the structure.
  */
 	Lf->access = Lf->lock = ' ';
 	Lf->dev_def = Lf->inp_ty = Lf->is_com = Lf->is_nfs = Lf->is_stream
-		    = Lf->lmi_srch = Lf->nlink_def = Lf->off_def = Lf->sz_def
-		    = Lf->rdev_def
-		    = (unsigned char)0;
+	    = Lf->lmi_srch = Lf->nlink_def = Lf->off_def = Lf->sz_def
+	    = Lf->rdev_def
+	    = (unsigned char)0;
 	Lf->li[0].af = Lf->li[1].af = 0;
 	Lf->lts.type = -1;
 	Lf->nlink = 0l;
@@ -181,10 +175,10 @@ alloc_lfile(nm, num)
 #if	defined(HASSOOPT)
 	Lf->lts.kai = Lf->lts.ltm = 0;
 	Lf->lts.opt = Lf->lts.qlen = Lf->lts.qlim = Lf->lts.pqlen
-		    = (unsigned int)0;
+	    = (unsigned int)0;
 	Lf->lts.rbsz = Lf->lts.sbsz = (unsigned long)0;
 	Lf->lts.qlens = Lf->lts.qlims = Lf->lts.pqlens = Lf->lts.rbszs
-		      = Lf->lts.sbszs = (unsigned char)0;
+	    = Lf->lts.sbszs = (unsigned char)0;
 #endif	/* defined(HASSOOPT) */
 
 #if	defined(HASSOSTATE)
@@ -257,8 +251,8 @@ alloc_lfile(nm, num)
 /*
  * See if the file descriptor has been selected.
  */
-	if (!Fdl || (!nm && num < 0))
-	    return;
+	    if (!Fdl || (!nm && num < 0))
+		return;
 	fds = ck_fd_status(nm, num);
 	switch (FdlTy) {
 	case 0:			/* inclusion list */
@@ -290,12 +284,12 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
 
 	if (!Lproc) {
 	    if (!(Lproc = (struct lproc *)malloc(
-			  (MALLOC_S)(LPROCINCR * sizeof(struct lproc)))))
+						 (MALLOC_S)(LPROCINCR * sizeof(struct lproc)))))
 	    {
 		(void) fprintf(stderr,
 		    "%s: no malloc space for %d local proc structures\n",
 		    Pn, LPROCINCR);
-		Exit(1);
+		Error();
 	    }
 	    sz = LPROCINCR;
 	} else if ((Nlproc + 1) > sz) {
@@ -306,7 +300,7 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
 		(void) fprintf(stderr,
 		    "%s: no realloc space for %d local proc structures\n",
 		    Pn, sz);
-		Exit(1);
+		Error();
 	    }
 	}
 	Lp = &Lproc[Nlproc++];
@@ -334,7 +328,7 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
 	    (void) fprintf(stderr, "%s: PID %d, no space for command name: ",
 		Pn, pid);
 	    safestrprt(cmd, stderr, 1);
-	    Exit(1);
+	    Error();
 	}
 
 #if	defined(HASZONES)
@@ -343,7 +337,7 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
  */
 	Lp->zn = (char *)NULL;
 #endif	/* defined(HASZONES) */
- 
+
 #if	defined(HASSELINUX)
 /*
  * Clear the security context pointer.  The dialect's own code will
@@ -570,7 +564,7 @@ free_lproc(lp)
 	    CLRLFILEADD(lf)
 #endif	/* defined(HASLFILEADD) && defined(CLRLFILEADD) */
 
-	    nf = lf->next;
+		nf = lf->next;
 	    (void) free((FREE_P *)lf);
 	}
 	lp->file = (struct lfile *)NULL;
@@ -613,7 +607,7 @@ is_cmd_excl(cmd, pss, sf)
 /*
  * The command is not excluded if no command selection was requested,
  * or if its name matches any -c <command> specification.
- * 
+ *
  */
 	if ((Selflags & SELCMD) == 0)
 	    return(0);
@@ -687,7 +681,7 @@ int
 #if	defined(HASTASKS)
 is_proc_excl(pid, pgid, uid, pss, sf, tid)
 #else	/* !defined(HASTASKS) */
-is_proc_excl(pid, pgid, uid, pss, sf)
+	is_proc_excl(pid, pgid, uid, pss, sf)
 #endif	/* defined(HASTASKS) */
 
 	int pid;			/* Process ID */
@@ -697,7 +691,7 @@ is_proc_excl(pid, pgid, uid, pss, sf)
 	short *sf;			/* select flags for lproc */
 
 #if	defined(HASTASKS)
-	int tid;			/* task ID (not a task if zero) */
+int tid;			/* task ID (not a task if zero) */
 #endif	/* defined(HASTASKS) */
 
 {
@@ -1016,7 +1010,7 @@ process_pinfo(f)
 					 */
 {
 	pxinfo_t *pp;			/* previous pipe info */
-	
+
 	if (!FeptE)
 	    return;
 	for (Lf = Lp->file; Lf; Lf = Lf->next) {
@@ -1099,9 +1093,9 @@ prt_pinfo(pp, ps)
 	if (ps) {
 
 	/*
-	* Endpoint files have been selected, so mark this
-	* one for selection later. Set the type to PIPE.
-	*/
+	 * Endpoint files have been selected, so mark this
+	 * one for selection later. Set the type to PIPE.
+	 */
 	    ef->chend = CHEND_PIPE;
 	    ep->ept |= EPT_PIPE_END;
 	}
@@ -1164,7 +1158,7 @@ process_psxmqinfo(f)
 		    Lf->sf = Selflags;
 		    Lp->pss |= PS_SEC;
 		    do {
-		      if ((pp = find_psxmqinfo(Lp->pid, Lf, pp))) {
+			if ((pp = find_psxmqinfo(Lp->pid, Lf, pp))) {
 			    prt_psxmqinfo(pp, 0);
 			    pp = pp->next;
 			}
@@ -1205,9 +1199,9 @@ prt_psxmqinfo(pp, ps)
 	if (ps) {
 
 	/*
-	* Endpoint files have been selected, so mark this
-	* one for selection later. Set the type to posix mq.
-	*/
+	 * Endpoint files have been selected, so mark this
+	 * one for selection later. Set the type to posix mq.
+	 */
 	    ef->chend = CHEND_PSXMQ;
 	    ep->ept |= EPT_PSXMQ_END;
 	}
@@ -1311,9 +1305,9 @@ prt_evtfdinfo(pp, ps)
 	if (ps) {
 
 	/*
-	* Endpoint files have been selected, so mark this
-	* one for selection later. Set the type to PIPE.
-	*/
+	 * Endpoint files have been selected, so mark this
+	 * one for selection later. Set the type to PIPE.
+	 */
 	    ef->chend = CHEND_EVTFD;
 	    ep->ept |= EPT_EVTFD_END;
 	}
@@ -1454,7 +1448,7 @@ print_proc()
 	    if (FieldSel[LSOF_FIX_ZONE].st && Fzone && Lp->zn)
 		(void) printf("%c%s%c", LSOF_FID_ZONE, Lp->zn, Terminator);
 #endif	/* defined(HASZONES) */
- 
+
 #if	defined(HASSELINUX)
 	    if (FieldSel[LSOF_FIX_CNTX].st && Fcntx && Lp->cntx && CntxStatus)
 		(void) printf("%c%s%c", LSOF_FID_CNTX, Lp->cntx, Terminator);
@@ -1585,12 +1579,8 @@ print_proc()
 	    if (FieldSel[LSOF_FIX_SIZE].st && Lf->sz_def) {
 		putchar(LSOF_FID_SIZE);
 
-#if	defined(HASPRINTSZ)
-		cp = HASPRINTSZ(Lf);
-#else	/* !defined(HASPRINTSZ) */
 		(void) snpf(buf, sizeof(buf), SzOffFmt_d, Lf->sz);
 		cp = buf;
-#endif	/* defined(HASPRINTSZ) */
 
 		(void) printf("%s", cp);
 		putchar(Terminator);
